==> kjy-center-api-0.1.0-dev-lizhi-20190610.020534-24-sources.jar: cn/com/duiba/kjy/api/remoteservice/RemoteUserVisitService.java <==
package cn.com.duiba.kjy.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.dto.TodayVisitDto;
import cn.com.duiba.kjy.api.dto.UserVisitedContentDto;
import cn.com.duiba.kjy.api.dto.UsersVisitDto;
import cn.com.duiba.kjy.api.params.Page;
import cn.com.duiba.kjy.api.params.SearchVisitListParam;
import cn.com.duiba.kjy.api.params.UserVisitContentParam;
import cn.com.duiba.kjy.api.params.UserVisitParam;

import java.util.List;
import java.util.Map;

/**
 * Created by zhangshun on 2019/2/13.
 */
@AdvancedFeignClient
public interface RemoteUserVisitService {

    /**
     * 保存访问记录
     *
     * @param dto
     * @return
     */
    Long save(UsersVisitDto dto);

    /**
     * 根据用户ID和销售员ID查询最后一条记录
     *
     * @deprecated 已废弃 请使用 findLastByScid 接口
     *
     * @param visitId   用户ID
     * @param sellerId 销售员ID
     * @param type     访问类型
     * @return
     */
    @Deprecated
    UsersVisitDto findLastByParam(Long visitId, Long sellerId, String type);

    /**
     * 根据用户ID和销售员ID查询最后一条记录
     *
     * @param visitId   用户ID
     * @param sellerId 销售员ID
     * @return
     */
    Integer countByUserAndSeller(Long visitId, Long sellerId);

    /**
     * 根据用户ID和销售员ID查询最后一条记录
     *
     * @param visitId   用户ID
     * @param sellerId 销售员ID
     * @param scid     销售员内容ID
     * @return
     */
    UsersVisitDto findLastByScid(Long visitId, Long sellerId, Long scid);

    /**
     * 查询文章访问记录列表
     *
     * @param searchVisitListParam
     * @return
     */
    Page<UsersVisitDto> getCustomerVisitList(SearchVisitListParam searchVisitListParam);

    Integer selectVisitCount(SearchVisitListParam param);

    /**
     * 查询用户浏览记录
     *
     * @param param
     * @return
     */
    Page<UserVisitedContentDto> selectUserVisitedContents(UserVisitContentParam param);

    /**
     * 查询单篇文章的访问记录
     *
     * @param param
     * @return
     */
    Page<UsersVisitDto> contentVisitInfo(SearchVisitListParam param);

    /**
     * 查询发布的单篇文章访问总时长
     *
     * @param sellerId 销售id
     * @param scId     销售文章id
     * @return
     */
    Long getTotalReadDuration(Long sellerId, Long scId);

    /**
     * 更新阅读时长
     *
     * @param id
     * @return
     */
    Boolean updateDuration(Long id, Integer duration);

    /**
     * 批量查询每篇文章访问总时长
     *
     * @param scIds
     * @return
     */
    Map<Long, Long> getReadDurationMap(List<Long> scIds);

    /**
     * 批量获取每篇文章访问总人数
     * @param scIds
     * @return
     */
    Map<Long, Integer> getReadNumMap(List<Long> scIds);

    /**
     * 批量修改客户绑定关系
     * @param sellerId
     * @param visitId
     * @return
     */
    Integer updateSellerUserBind(Long sellerId, Long visitId);

    TodayVisitDto countTodayBySeller(UserVisitParam param);

    Boolean markVisitAlready(Long sellerId);

    Long countTodayVisitor(String openId);

    Integer countVisitBySeller(Long sellerId);
}

==> kjy-center-api-0.4.0-lizhi1-20190722.111328-1-sources.jar: cn/com/duiba/kjy/api/remoteservice/RemoteUserVisitService.java <==
package cn.com.duiba.kjy.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.dto.TodayVisitDto;
import cn.com.duiba.kjy.api.dto.UserVisitedContentDto;
import cn.com.duiba.kjy.api.dto.UsersVisitDto;
import cn.com.duiba.kjy.api.params.Page;
import cn.com.duiba.kjy.api.params.SearchVisitListParam;
import cn.com.duiba.kjy.api.params.UserVisitContentParam;
import cn.com.duiba.kjy.api.params.UserVisitParam;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * Created by zhangshun on 2019/2/13.
 */
@AdvancedFeignClient
public interface RemoteUserVisitService {

    /**
     * 保存访问记录
     *
     * @param dto
     * @return
     */
    Long save(UsersVisitDto dto);

    /**
     * 根据用户ID和销售员ID查询最后一条记录
     *
     * @deprecated 已废弃 请使用 findLastByScid 接口
     *
     * @param visitId   用户ID
     * @param sellerId 销售员ID
     * @param type     访问类型
     * @return
     */
    @Deprecated
    UsersVisitDto findLastByParam(Long visitId, Long sellerId, String type);

    /**
     * 根据用户ID和销售员ID查询最后一条记录
     *
     * @param visitId   用户ID
     * @param sellerId 销售员ID
     * @return
     */
    Integer countByUserAndSeller(Long visitId, Long sellerId);

    /**
     * 根据用户ID和销售员ID查询最后一条记录
     *
     * @param visitId   用户ID
     * @param sellerId 销售员ID
     * @param scid     销售员内容ID
     * @return
     */
    UsersVisitDto findLastByScid(Long visitId, Long sellerId, Long scid);

    /**
     * 查询文章访问记录列表
     *
     * @param searchVisitListParam
     * @return
     */
    Page<UsersVisitDto> getCustomerVisitList(SearchVisitListParam searchVisitListParam);

    Integer selectVisitCount(SearchVisitListParam param);

    /**
     * 查询用户浏览记录
     *
     * @param param
     * @return
     */
    Page<UserVisitedContentDto> selectUserVisitedContents(UserVisitContentParam param);

    /**
     * 查询单篇文章的访问记录
     *
     * @param param
     * @return
     */
    Page<UsersVisitDto> contentVisitInfo(SearchVisitListParam param);

    /**
     * 查询发布的单篇文章访问总时长
     *
     * @param sellerId 销售id
     * @param scId     销售文章id
     * @return
     */
    Long getTotalReadDuration(Long sellerId, Long scId);

    /**
     * 更新阅读时长
     *
     * @param id
     * @return
     */
    Boolean updateDuration(Long id, Integer duration);

    /**
     * 批量查询每篇文章访问总时长
     *
     * @param scIds
     * @return
     */
    Map<Long, Long> getReadDurationMap(List<Long> scIds);

    /**
     * 批量获取每篇文章访问总人数
     * @param scIds
     * @return
     */
    Map<Long, Integer> getReadNumMap(List<Long> scIds);

    /**
     * 批量修改客户绑定关系
     * @param sellerId
     * @param visitId
     * @return
     */
    Integer updateSellerUserBind(Long sellerId, Long visitId);

    TodayVisitDto countTodayBySeller(UserVisitParam param);

    Boolean markVisitAlready(Long sellerId, Integer type);

    Long countTodayVisitor(String openId);

    Integer countVisitBySeller(Long sellerId);

    /**
     * 根据时间区间获取代理人访问人数
     * @param sellerId
     * @return
     */
    Integer countVisitNumByTime(Long sellerId, Date startDate, Date endDate);

    /**
     * 根据代理人Id和客户userId获取总数
     * @param sellerId
     * @param userId
     * @return
     */
    Integer countNumBySellerIdAndUserId(Long sellerId, Long userId);

    /**
     * 列表查询
     * @param param
     * @return
     */
    List<UsersVisitDto> listByParams(UserVisitParam param);


    /**
     * 获取24小时内代理人击败百分比
     * @param sellId
     * @return
     */
    String getSellerBeatPercentage(Long sellId);

    /**
     * 根据主键标记已读访问
     * @param id
     * @return
     */
    Integer markAlreadyReadById(Long id);

}
